Package 'plot3logit'

Title: Ternary Plots for Trinomial Regression Models
Description: An implementation of the ternary plot for interpreting regression coefficients of trinomial regression models, as proposed in Santi, Dickson and Espa (2019) <doi:10.1080/00031305.2018.1442368>. Ternary plots can be drawn using either 'ggtern' package (based on 'ggplot2') or 'Ternary' package (based on standard graphics). The package and its features are illustrated in Santi, Dickson, Espa and Giuliani (2022) <doi:10.18637/jss.v103.c01>.
Authors: Flavio Santi [cre, aut] , Maria Michela Dickson [aut] , Giuseppe Espa [aut] , Diego Giuliani [aut]
Maintainer: Flavio Santi <[email protected]>
License: GPL (>=2)
Version: 3.2.0
Built: 2026-05-23 15:13:17 UTC
Source: https://github.com/f-santi/plot3logit

Help Index